<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Website</name>
    <message>
        <location filename="../WebsiteInit.js" line="+2"/>
        <source>Visit &amp;Website</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Odwiedź &amp;stronę</translatorcomment>
        <translation>Otwórz &amp;stronę programu</translation>
    </message>
</context>
</TS>
